@@ -20,111 +20,6 @@
 #include <QPainter>
 #include <QPaintEvent>
 
-Border::Border(QObject *parent) :
-    QObject(parent),
-    m_pen(Qt::black)
-{
-}
-
-Border::~Border() {}
-
-QColor Border::color() const {
-    return m_pen.color();
-}
-
-void Border::setColor(const QColor &color) {
-    if (color != this->color()) {
-        m_pen.setColor(color);
-        emit colorChanged();
-    }
-}
-
-int Border::width() const {
-    return m_pen.width();
-}
-
-void Border::setWidth(int width) {
-    if (width != this->width()) {
-        m_pen.setWidth(width);
-        emit widthChanged();
-    }
-}
-
-void Border::resetWidth() {
-    this->setWidth(0);
-}
-
-QPen Border::pen() const {
-    return m_pen;
-}
-
-GradientStop::GradientStop(QObject *parent) :
-    QObject(parent)
-{
-}
-
-GradientStop::~GradientStop() {}
-
-QColor GradientStop::color() const {
-    return m_stop.second;
-}
-
-void GradientStop::setColor(const QColor &color) {
-    if (color != this->color()) {
-        m_stop.second = color;
-        emit colorChanged();
-    }
-}
-
-qreal GradientStop::position() const {
-    return m_stop.first;
-}
-
-void GradientStop::setPosition(qreal pos) {
-    if (pos != this->position()) {
-        m_stop.first = pos;
-        emit positionChanged();
-    }
-}
-
-QGradientStop GradientStop::stop() const {
-    return m_stop;
-}
-
-Gradient::Gradient(QObject *parent) :
-    QObject(parent)
-{
-}
-
-Gradient::~Gradient() {}
-
-QGradientStops Gradient::stops() const {
-    QGradientStops s(m_stops.size());
-
-    for (int i = 0; i < m_stops.size(); i++) {
-        s.append(m_stops.at(i)->stop());
-    }
-
-    return s;
-}
-
-QDeclarativeListProperty<GradientStop> Gradient::qmlStops() {
-    return QDeclarativeListProperty<GradientStop>(this, 0, Gradient::stops_append);
-}
-
-void Gradient::stops_append(QDeclarativeListProperty<GradientStop> *list, GradientStop *stop) {
-    if (!stop) {
-        return;
-    }
-
-    if (Gradient *gradient = qobject_cast<Gradient*>(list->object)) {
-        gradient->m_stops.append(stop);
-        emit gradient->stopsChanged();
-        gradient->connect(stop, SIGNAL(colorChanged()), gradient, SIGNAL(stopsChanged()));
-        gradient->connect(stop, SIGNAL(positionChanged()), gradient, SIGNAL(stopsChanged()));
-    }
-}
-
 Rectangle::Rectangle(QWidget *parent) :
     Item(*new RectanglePrivate(this), parent)
 {
