@@ -73,19 +73,6 @@ void ToolBar::setOpacity(qreal opacity) {
     }
 }
 
-void ToolBar::setFocus(bool focus) {
-    Q_D(const ToolBar);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 AnchorLine ToolBar::left() const {
     Q_D(const ToolBar);
 
@@ -127,6 +114,9 @@ void ToolBar::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
