@@ -37,6 +37,7 @@ class ValueButton : public QMaemo5ValueButton, public QDeclarativeParserStatus
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
     Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
     Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
+    Q_PROPERTY(bool pressed READ isDown WRITE setDown NOTIFY pressedChanged)
     Q_PROPERTY(ValueSelector* selector READ selector WRITE setSelector)
     Q_PROPERTY(QString icon READ iconSource WRITE setIconSource NOTIFY iconChanged)
     Q_PROPERTY(QString shortcut READ shortcutString WRITE setShortcutString NOTIFY shorcutChanged)
@@ -93,6 +94,7 @@ signals:
     void opacityChanged();
     void visibleChanged();
     void enabledChanged();
+    void pressedChanged();
     void focusChanged();
     void iconChanged();
     void shortcutChanged();
