@@ -155,9 +155,11 @@ public:
         
         switch (state) {
         case Transitioning:
+            readyToPlay = false;
             status = MediaStatus::Loading;
             break;
         case Playing:
+            readyToPlay = false;
             status = MediaStatus::Playing;
             
             if (tickInterval > 0) {
@@ -210,6 +212,7 @@ public:
             
             break;
         default:
+            readyToPlay = false;
             break;
         }
         
@@ -381,6 +384,7 @@ AudioPlayer::AudioPlayer(QObject *parent) :
                   this, SLOT(_q_onStatusReady(MafwPlaylist*,uint,MafwPlayState,const char*,QString)));
     this->connect(d->mafwRenderer, SIGNAL(signalGetPosition(int,QString)), this, SLOT(_q_onPositionChanged(int)));
     this->connect(d->mafwRenderer, SIGNAL(signalGetVolume(int)), this, SLOT(_q_onVolumeChanged(int)));
+    this->connect(d->mafwRenderer, SIGNAL(bufferingInfo(float)), this, SLOT(_q_onBufferProgressChanged(float)));
             
     QDBusConnection::sessionBus().connect("com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer",
                                           "/com/nokia/mafw/renderer/gstrenderer",
@@ -576,10 +580,6 @@ void AudioPlayer::setTickInterval(int interval) {
 }
 
 void AudioPlayer::play() {
-    if (this->isPlaying()) {
-        return;
-    }
-    
     Q_D(AudioPlayer);
     
     if (this->isPaused()) {
